@@ -660,25 +660,26 @@ class DragonGather(TaskScheduler):
                 print("IDEX %s Exception" % idex, ex)
                 print("Error en obtención de data desde rethinkdb")
                 rc.logerror(
-                    f'''IDEX = {idex}, Error en la obtención de datos para estación {code} en {ex}'''
-                kwargs["origin_exception"]=f"PD_TO4_00 + {code} + {idex} + {ex}"
+                    f'''IDEX = {idex}, Error en la obtención de datos para
+                    estación {code} en {ex}''')
+                kwargs["origin_exception"] = f"PD_TO4_00 + {code} + {idex} + {ex}"
                 log.exception(kwargs["origin_exception"])
-                self.rethinkdb_origin[ids]=False
+                self.rethinkdb_origin[ids] = False
                 rc.close()
                 del rc
-                rc=None
-                wargs=[ipt, ids, v, [
+                rc = None
+                wargs = [ipt, ids, v, [
                     di, control, (rc, rc_enu), process_data]]
                 return wargs, kwargs
 
             # signal.message({"msg":"cursor len %s" %len(cursor)})
-            list_ok=[]
+            list_ok = []
             for c in cursor:
                 if check_gsof(c):
                     try:
-                        result=process_data.manage_data(c)
+                        result = process_data.manage_data(c)
                         # to_plot = geojson2json(result)
-                        to_db=geojson2json(result, destiny='db')
+                        to_db = geojson2json(result, destiny='db')
                         # result_enu =
                         try:
                             await wait_for(
@@ -688,8 +689,7 @@ class DragonGather(TaskScheduler):
                                ConnectionResetError,
                                ConnectionAbortedError) as conn_error:
                            idex=my_random_string(uin)
-                           kwargs["origin_exception"]=f'''PD_TO3_-1 + {idex} +
-            {code} + {conn_error}, ConnectionClosed rc_enu connection....'''
+                           kwargs["origin_exception"]=f'''PD_TO3_-1 + {idex} + {code} + {conn_error}, ConnectionClosed rc_enu connection....'''
                            log.exception(kwargs["origin_exception"])
                            self.rethinkdb_origin[ids]=False
                            bprint(kwargs)
